@@ -5,7 +5,7 @@
 
     Sphinx extension with Python doc-specific markup.
 
-    :copyright: 2008 by Georg Brandl.
+    :copyright: 2008, 2009 by Georg Brandl.
     :license: Python license.
 """
 
@@ -13,6 +13,14 @@ ISSUE_URI = 'http://bugs.python.org/issue%s'
 
 from docutils import nodes, utils
 
+# monkey-patch reST parser to disable alphabetic and roman enumerated lists
+from docutils.parsers.rst.states import Body
+Body.enum.converters['loweralpha'] = \
+    Body.enum.converters['upperalpha'] = \
+    Body.enum.converters['lowerroman'] = \
+    Body.enum.converters['upperroman'] = lambda x: None
+
+
 def issue_role(typ, rawtext, text, lineno, inliner, options={}, content=[]):
     issue = utils.unescape(text)
     text = 'issue ' + issue
@@ -27,19 +35,17 @@ pydoc_topic_labels = [
     'attribute-access', 'attribute-references', 'augassign', 'binary',
     'bitwise', 'bltin-code-objects', 'bltin-ellipsis-object',
     'bltin-file-objects', 'bltin-null-object', 'bltin-type-objects', 'booleans',
-    'break', 'callable-types', 'calls', 'class', 'coercion-rules',
-    'comparisons', 'compound', 'context-managers', 'continue', 'conversions',
-    'customization', 'debugger', 'del', 'dict', 'dynamic-features', 'else',
-    'exceptions', 'exec', 'execmodel', 'exprlists', 'floating', 'for',
-    'formatstrings', 'function', 'global', 'id-classes', 'identifiers', 'if',
-    'imaginary', 'import', 'in', 'integers', 'lambda', 'lists', 'naming',
-    'numbers', 'numeric-types', 'objects', 'operator-summary', 'pass', 'power',
-    'print', 'raise', 'return', 'sequence-methods', 'sequence-types',
-    'shifting', 'slicings', 'specialattrs', 'specialnames',
-    'string-conversions', 'string-methods', 'strings', 'subscriptions', 'truth',
-    'try', 'types', 'typesfunctions', 'typesmapping', 'typesmethods',
-    'typesmodules', 'typesseq', 'typesseq-mutable', 'unary', 'while', 'with',
-    'yield'
+    'break', 'callable-types', 'calls', 'class', 'comparisons', 'compound',
+    'context-managers', 'continue', 'conversions', 'customization', 'debugger',
+    'del', 'dict', 'dynamic-features', 'else', 'exceptions', 'execmodel',
+    'exprlists', 'floating', 'for', 'formatstrings', 'function', 'global',
+    'id-classes', 'identifiers', 'if', 'imaginary', 'import', 'in', 'integers',
+    'lambda', 'lists', 'naming', 'numbers', 'numeric-types', 'objects',
+    'operator-summary', 'pass', 'power', 'raise', 'return', 'sequence-types',
+    'shifting', 'slicings', 'specialattrs', 'specialnames', 'string-methods',
+    'strings', 'subscriptions', 'truth', 'try', 'types', 'typesfunctions',
+    'typesmapping', 'typesmethods', 'typesmodules', 'typesseq',
+    'typesseq-mutable', 'unary', 'while', 'with', 'yield'
 ]
 
 from os import path
@@ -47,8 +53,10 @@ from time import asctime
 from pprint import pformat
 from docutils.io import StringOutput
 from docutils.utils import new_document
-from sphinx.builder import Builder
-from sphinx.textwriter import TextWriter
+
+from sphinx.builders import Builder
+from sphinx.writers.text import TextWriter
+
 
 class PydocTopicsBuilder(Builder):
     name = 'pydoc-topics'
@@ -64,7 +72,9 @@ class PydocTopicsBuilder(Builder):
 
     def write(self, *ignored):
         writer = TextWriter(self)
-        for label in self.status_iterator(pydoc_topic_labels, 'building topics... '):
+        for label in self.status_iterator(pydoc_topic_labels,
+                                          'building topics... ',
+                                          length=len(pydoc_topic_labels)):
             if label not in self.env.labels:
                 self.warn('label %r not in documentation' % label)
                 continue
@@ -74,16 +84,19 @@ class PydocTopicsBuilder(Builder):
             document.append(doctree.ids[labelid])
             destination = StringOutput(encoding='utf-8')
             writer.write(document, destination)
-            self.topics[label] = writer.output
+            self.topics[label] = str(writer.output)
 
     def finish(self):
-        f = open(path.join(self.outdir, 'pydoc_topics.py'), 'w')
+        f = open(path.join(self.outdir, 'topics.py'), 'w')
         try:
             f.write('# Autogenerated by Sphinx on %s\n' % asctime())
             f.write('topics = ' + pformat(self.topics) + '\n')
         finally:
             f.close()
 
+# Support for checking for suspicious markup
+
+import suspicious
 
 # Support for documenting Opcodes
 
@@ -108,5 +121,7 @@ def parse_opcode_signature(env, sig, signode):
 def setup(app):
     app.add_role('issue', issue_role)
     app.add_builder(PydocTopicsBuilder)
+    app.add_builder(suspicious.CheckSuspiciousMarkupBuilder)
     app.add_description_unit('opcode', 'opcode', '%s (opcode)',
                              parse_opcode_signature)
+    app.add_description_unit('2to3fixer', '2to3fixer', '%s (2to3 fixer)')
