@@ -7,43 +7,43 @@ class SlicesTestCase(unittest.TestCase):
     def test_getslice_cint(self):
         a = (c_int * 100)(*range(1100, 1200))
         b = list(range(1100, 1200))
-        self.failUnlessEqual(a[0:2], b[0:2])
-        self.failUnlessEqual(a[0:2:], b[0:2:])
-        self.failUnlessEqual(len(a), len(b))
-        self.failUnlessEqual(a[5:7], b[5:7])
-        self.failUnlessEqual(a[5:7:], b[5:7:])
-        self.failUnlessEqual(a[-1], b[-1])
-        self.failUnlessEqual(a[:], b[:])
-        self.failUnlessEqual(a[::], b[::])
-        self.failUnlessEqual(a[10::-1], b[10::-1])
-        self.failUnlessEqual(a[30:20:-1], b[30:20:-1])
-        self.failUnlessEqual(a[:12:6], b[:12:6])
-        self.failUnlessEqual(a[2:6:4], b[2:6:4])
+        self.assertEqual(a[0:2], b[0:2])
+        self.assertEqual(a[0:2:], b[0:2:])
+        self.assertEqual(len(a), len(b))
+        self.assertEqual(a[5:7], b[5:7])
+        self.assertEqual(a[5:7:], b[5:7:])
+        self.assertEqual(a[-1], b[-1])
+        self.assertEqual(a[:], b[:])
+        self.assertEqual(a[::], b[::])
+        self.assertEqual(a[10::-1], b[10::-1])
+        self.assertEqual(a[30:20:-1], b[30:20:-1])
+        self.assertEqual(a[:12:6], b[:12:6])
+        self.assertEqual(a[2:6:4], b[2:6:4])
 
         a[0:5] = range(5, 10)
-        self.failUnlessEqual(a[0:5], list(range(5, 10)))
-        self.failUnlessEqual(a[0:5:], list(range(5, 10)))
-        self.failUnlessEqual(a[4::-1], list(range(9, 4, -1)))
+        self.assertEqual(a[0:5], list(range(5, 10)))
+        self.assertEqual(a[0:5:], list(range(5, 10)))
+        self.assertEqual(a[4::-1], list(range(9, 4, -1)))
 
     def test_setslice_cint(self):
         a = (c_int * 100)(*range(1100, 1200))
         b = list(range(1100, 1200))
 
         a[32:47] = list(range(32, 47))
-        self.failUnlessEqual(a[32:47], list(range(32, 47)))
+        self.assertEqual(a[32:47], list(range(32, 47)))
         a[32:47] = range(132, 147)
-        self.failUnlessEqual(a[32:47:], list(range(132, 147)))
+        self.assertEqual(a[32:47:], list(range(132, 147)))
         a[46:31:-1] = range(232, 247)
-        self.failUnlessEqual(a[32:47:1], list(range(246, 231, -1)))
+        self.assertEqual(a[32:47:1], list(range(246, 231, -1)))
 
         a[32:47] = range(1132, 1147)
-        self.failUnlessEqual(a[:], b)
+        self.assertEqual(a[:], b)
         a[32:47:7] = range(3)
         b[32:47:7] = range(3)
-        self.failUnlessEqual(a[:], b)
+        self.assertEqual(a[:], b)
         a[33::-3] = range(12)
         b[33::-3] = range(12)
-        self.failUnlessEqual(a[:], b)
+        self.assertEqual(a[:], b)
 
         from operator import setitem
 
@@ -65,12 +65,12 @@ class SlicesTestCase(unittest.TestCase):
         dll.my_strdup.restype = POINTER(c_char)
         dll.my_free.restype = None
         res = dll.my_strdup(s)
-        self.failUnlessEqual(res[:len(s)], s)
-        self.failUnlessEqual(res[:3], s[:3])
-        self.failUnlessEqual(res[:len(s):], s)
-        self.failUnlessEqual(res[len(s)-1:-1:-1], s[::-1])
-        self.failUnlessEqual(res[len(s)-1:5:-7], s[:5:-7])
-        self.failUnlessEqual(res[0:-1:-1], s[0::-1])
+        self.assertEqual(res[:len(s)], s)
+        self.assertEqual(res[:3], s[:3])
+        self.assertEqual(res[:len(s):], s)
+        self.assertEqual(res[len(s)-1:-1:-1], s[::-1])
+        self.assertEqual(res[len(s)-1:5:-7], s[:5:-7])
+        self.assertEqual(res[0:-1:-1], s[0::-1])
 
         import operator
         self.assertRaises(ValueError, operator.getitem,
@@ -88,8 +88,8 @@ class SlicesTestCase(unittest.TestCase):
 
         dll.my_strdup.restype = POINTER(c_byte)
         res = dll.my_strdup(s)
-        self.failUnlessEqual(res[:len(s)], list(range(ord("a"), ord("z")+1)))
-        self.failUnlessEqual(res[:len(s):], list(range(ord("a"), ord("z")+1)))
+        self.assertEqual(res[:len(s)], list(range(ord("a"), ord("z")+1)))
+        self.assertEqual(res[:len(s):], list(range(ord("a"), ord("z")+1)))
         dll.my_free(res)
 
     def test_char_ptr_with_free(self):
@@ -109,7 +109,7 @@ class SlicesTestCase(unittest.TestCase):
         dll.my_strdup.errcheck = errcheck
         try:
             res = dll.my_strdup(s)
-            self.failUnlessEqual(res, s.decode())
+            self.assertEqual(res, s.decode())
         finally:
             del dll.my_strdup.errcheck
 
@@ -118,11 +118,11 @@ class SlicesTestCase(unittest.TestCase):
         s = b"abcdefghijklmnopqrstuvwxyz\0"
 
         p = (c_char * 27)(*s)
-        self.failUnlessEqual(p[:], s)
-        self.failUnlessEqual(p[::], s)
-        self.failUnlessEqual(p[::-1], s[::-1])
-        self.failUnlessEqual(p[5::-2], s[5::-2])
-        self.failUnlessEqual(p[2:5:-3], s[2:5:-3])
+        self.assertEqual(p[:], s)
+        self.assertEqual(p[::], s)
+        self.assertEqual(p[::-1], s[::-1])
+        self.assertEqual(p[5::-2], s[5::-2])
+        self.assertEqual(p[2:5:-3], s[2:5:-3])
 
 
     try:
@@ -138,10 +138,10 @@ class SlicesTestCase(unittest.TestCase):
             dll.my_wcsdup.argtypes = POINTER(c_wchar),
             dll.my_free.restype = None
             res = dll.my_wcsdup(s)
-            self.failUnlessEqual(res[:len(s)], s)
-            self.failUnlessEqual(res[:len(s):], s)
-            self.failUnlessEqual(res[len(s)-1:-1:-1], s[::-1])
-            self.failUnlessEqual(res[len(s)-1:5:-7], s[:5:-7])
+            self.assertEqual(res[:len(s)], s)
+            self.assertEqual(res[:len(s):], s)
+            self.assertEqual(res[len(s)-1:-1:-1], s[::-1])
+            self.assertEqual(res[len(s)-1:5:-7], s[:5:-7])
 
             import operator
             self.assertRaises(TypeError, operator.setitem,
@@ -158,10 +158,10 @@ class SlicesTestCase(unittest.TestCase):
                 return
             res = dll.my_wcsdup(s)
             tmpl = list(range(ord("a"), ord("z")+1))
-            self.failUnlessEqual(res[:len(s)-1], tmpl)
-            self.failUnlessEqual(res[:len(s)-1:], tmpl)
-            self.failUnlessEqual(res[len(s)-2:-1:-1], tmpl[::-1])
-            self.failUnlessEqual(res[len(s)-2:5:-7], tmpl[:5:-7])
+            self.assertEqual(res[:len(s)-1], tmpl)
+            self.assertEqual(res[:len(s)-1:], tmpl)
+            self.assertEqual(res[len(s)-2:-1:-1], tmpl[::-1])
+            self.assertEqual(res[len(s)-2:5:-7], tmpl[:5:-7])
             dll.my_free(res)
 
 ################################################################
