@@ -1,17 +1,19 @@
+# -*- coding: utf8 -*-
 """Tests for distutils.dist."""
-
-import distutils.cmd
-import distutils.dist
 import os
 import io
 import sys
 import unittest
 import warnings
 
-from test.support import TESTFN
+from distutils.dist import Distribution, fix_help_options
+from distutils.cmd import Command
+
+from test.support import TESTFN, captured_stdout
+from distutils.tests import support
 
 
-class test_dist(distutils.cmd.Command):
+class test_dist(Command):
     """Sample distutils extension command."""
 
     user_options = [
@@ -22,7 +24,7 @@ class test_dist(distutils.cmd.Command):
         self.sample_option = None
 
 
-class TestDistribution(distutils.dist.Distribution):
+class TestDistribution(Distribution):
     """Distribution subclasses that avoids the default search for
     configuration files.
 
@@ -34,14 +36,17 @@ class TestDistribution(distutils.dist.Distribution):
         return self._config_files
 
 
-class DistributionTestCase(unittest.TestCase):
+class DistributionTestCase(support.LoggingSilencer,
+                           unittest.TestCase):
 
     def setUp(self):
+        super(DistributionTestCase, self).setUp()
         self.argv = sys.argv[:]
         del sys.argv[1:]
 
     def tearDown(self):
         sys.argv[:] = self.argv
+        super(DistributionTestCase, self).tearDown()
 
     def create_distribution(self, configfiles=()):
         d = TestDistribution()
@@ -67,7 +72,7 @@ class DistributionTestCase(unittest.TestCase):
         self.assertEqual(d.get_command_packages(),
                          ["distutils.command", "foo.bar", "distutils.tests"])
         cmd = d.get_command_obj("test_dist")
-        self.assert_(isinstance(cmd, test_dist))
+        self.assertTrue(isinstance(cmd, test_dist))
         self.assertEqual(cmd.sample_option, "sometext")
 
     def test_command_packages_configfile(self):
@@ -96,11 +101,10 @@ class DistributionTestCase(unittest.TestCase):
         finally:
             os.unlink(TESTFN)
 
-
     def test_empty_options(self):
         # an empty options dictionary should not stay in the
         # list of attributes
-        klass = distutils.dist.Distribution
+        klass = Distribution
 
         # catching warnings
         warns = []
@@ -120,35 +124,60 @@ class DistributionTestCase(unittest.TestCase):
 
         self.assertEquals(len(warns), 0)
 
-class MetadataTestCase(unittest.TestCase):
+    def test_finalize_options(self):
+
+        attrs = {'keywords': 'one,two',
+                 'platforms': 'one,two'}
+
+        dist = Distribution(attrs=attrs)
+        dist.finalize_options()
+
+        # finalize_option splits platforms and keywords
+        self.assertEquals(dist.metadata.platforms, ['one', 'two'])
+        self.assertEquals(dist.metadata.keywords, ['one', 'two'])
+
+    def test_get_command_packages(self):
+        dist = Distribution()
+        self.assertEquals(dist.command_packages, None)
+        cmds = dist.get_command_packages()
+        self.assertEquals(cmds, ['distutils.command'])
+        self.assertEquals(dist.command_packages,
+                          ['distutils.command'])
+
+        dist.command_packages = 'one,two'
+        cmds = dist.get_command_packages()
+        self.assertEquals(cmds, ['distutils.command', 'one', 'two'])
+
+
+class MetadataTestCase(support.TempdirManager, support.EnvironGuard,
+                       unittest.TestCase):
 
     def test_simple_metadata(self):
         attrs = {"name": "package",
                  "version": "1.0"}
-        dist = distutils.dist.Distribution(attrs)
+        dist = Distribution(attrs)
         meta = self.format_metadata(dist)
-        self.assert_("Metadata-Version: 1.0" in meta)
-        self.assert_("provides:" not in meta.lower())
-        self.assert_("requires:" not in meta.lower())
-        self.assert_("obsoletes:" not in meta.lower())
+        self.assertTrue("Metadata-Version: 1.0" in meta)
+        self.assertTrue("provides:" not in meta.lower())
+        self.assertTrue("requires:" not in meta.lower())
+        self.assertTrue("obsoletes:" not in meta.lower())
 
     def test_provides(self):
         attrs = {"name": "package",
                  "version": "1.0",
                  "provides": ["package", "package.sub"]}
-        dist = distutils.dist.Distribution(attrs)
+        dist = Distribution(attrs)
         self.assertEqual(dist.metadata.get_provides(),
                          ["package", "package.sub"])
         self.assertEqual(dist.get_provides(),
                          ["package", "package.sub"])
         meta = self.format_metadata(dist)
-        self.assert_("Metadata-Version: 1.1" in meta)
-        self.assert_("requires:" not in meta.lower())
-        self.assert_("obsoletes:" not in meta.lower())
+        self.assertTrue("Metadata-Version: 1.1" in meta)
+        self.assertTrue("requires:" not in meta.lower())
+        self.assertTrue("obsoletes:" not in meta.lower())
 
     def test_provides_illegal(self):
-        self.assertRaises(ValueError,
-                          distutils.dist.Distribution,
+        self.assertRaises(ValueError, Distribution,
                           {"name": "package",
                            "version": "1.0",
                            "provides": ["my.pkg (splat)"]})
@@ -157,21 +186,20 @@ class MetadataTestCase(unittest.TestCase):
         attrs = {"name": "package",
                  "version": "1.0",
                  "requires": ["other", "another (==1.0)"]}
-        dist = distutils.dist.Distribution(attrs)
+        dist = Distribution(attrs)
         self.assertEqual(dist.metadata.get_requires(),
                          ["other", "another (==1.0)"])
         self.assertEqual(dist.get_requires(),
                          ["other", "another (==1.0)"])
         meta = self.format_metadata(dist)
-        self.assert_("Metadata-Version: 1.1" in meta)
-        self.assert_("provides:" not in meta.lower())
-        self.assert_("Requires: other" in meta)
-        self.assert_("Requires: another (==1.0)" in meta)
-        self.assert_("obsoletes:" not in meta.lower())
+        self.assertTrue("Metadata-Version: 1.1" in meta)
+        self.assertTrue("provides:" not in meta.lower())
+        self.assertTrue("Requires: other" in meta)
+        self.assertTrue("Requires: another (==1.0)" in meta)
+        self.assertTrue("obsoletes:" not in meta.lower())
 
     def test_requires_illegal(self):
-        self.assertRaises(ValueError,
-                          distutils.dist.Distribution,
+        self.assertRaises(ValueError, Distribution,
                           {"name": "package",
                            "version": "1.0",
                            "requires": ["my.pkg (splat)"]})
@@ -180,21 +208,20 @@ class MetadataTestCase(unittest.TestCase):
         attrs = {"name": "package",
                  "version": "1.0",
                  "obsoletes": ["other", "another (<1.0)"]}
-        dist = distutils.dist.Distribution(attrs)
+        dist = Distribution(attrs)
         self.assertEqual(dist.metadata.get_obsoletes(),
                          ["other", "another (<1.0)"])
         self.assertEqual(dist.get_obsoletes(),
                          ["other", "another (<1.0)"])
         meta = self.format_metadata(dist)
-        self.assert_("Metadata-Version: 1.1" in meta)
-        self.assert_("provides:" not in meta.lower())
-        self.assert_("requires:" not in meta.lower())
-        self.assert_("Obsoletes: other" in meta)
-        self.assert_("Obsoletes: another (<1.0)" in meta)
+        self.assertTrue("Metadata-Version: 1.1" in meta)
+        self.assertTrue("provides:" not in meta.lower())
+        self.assertTrue("requires:" not in meta.lower())
+        self.assertTrue("Obsoletes: other" in meta)
+        self.assertTrue("Obsoletes: another (<1.0)" in meta)
 
     def test_obsoletes_illegal(self):
-        self.assertRaises(ValueError,
-                          distutils.dist.Distribution,
+        self.assertRaises(ValueError, Distribution,
                           {"name": "package",
                            "version": "1.0",
                            "obsoletes": ["my.pkg (splat)"]})
@@ -207,47 +234,59 @@ class MetadataTestCase(unittest.TestCase):
     def test_custom_pydistutils(self):
         # fixes #2166
         # make sure pydistutils.cfg is found
-        old = {}
-        for env in ('HOME', 'HOMEPATH', 'HOMEDRIVE'):
-            value = os.environ.get(env)
-            old[env] = value
-            if value is not None:
-                del os.environ[env]
-
         if os.name == 'posix':
             user_filename = ".pydistutils.cfg"
         else:
             user_filename = "pydistutils.cfg"
 
-        curdir = os.path.dirname(__file__)
-        user_filename = os.path.join(curdir, user_filename)
+        temp_dir = self.mkdtemp()
+        user_filename = os.path.join(temp_dir, user_filename)
         f = open(user_filename, 'w')
         f.write('.')
         f.close()
 
         try:
-            dist = distutils.dist.Distribution()
+            dist = Distribution()
 
             # linux-style
             if sys.platform in ('linux', 'darwin'):
-                os.environ['HOME'] = curdir
+                self.environ['HOME'] = temp_dir
                 files = dist.find_config_files()
-                self.assert_(user_filename in files)
+                self.assertTrue(user_filename in files)
 
             # win32-style
             if sys.platform == 'win32':
                 # home drive should be found
-                os.environ['HOME'] = curdir
+                self.environ['HOME'] = temp_dir
                 files = dist.find_config_files()
-                self.assert_(user_filename in files,
+                self.assertTrue(user_filename in files,
                              '%r not found in %r' % (user_filename, files))
         finally:
-            for key, value in old.items():
-                if value is None:
-                    continue
-                os.environ[key] = value
             os.remove(user_filename)
 
+    def test_fix_help_options(self):
+        help_tuples = [('a', 'b', 'c', 'd'), (1, 2, 3, 4)]
+        fancy_options = fix_help_options(help_tuples)
+        self.assertEquals(fancy_options[0], ('a', 'b', 'c'))
+        self.assertEquals(fancy_options[1], (1, 2, 3))
+
+    def test_show_help(self):
+        # smoke test, just makes sure some help is displayed
+        dist = Distribution()
+        old_argv = sys.argv
+        sys.argv = []
+        try:
+            dist.help = 1
+            dist.script_name = 'setup.py'
+            with captured_stdout() as s:
+                dist.parse_command_line()
+        finally:
+            sys.argv = old_argv
+
+        output = [line for line in s.getvalue().split('\n')
+                  if line.strip() != '']
+        self.assertTrue(len(output) > 0)
+
 def test_suite():
     suite = unittest.TestSuite()
     suite.addTest(unittest.makeSuite(DistributionTestCase))
